@@ -2,6 +2,7 @@ from Products.Five.browser import BrowserView
 
 from getpaid.discount.browser.interfaces import IDiscountableMarker
 from getpaid.discount.browser.interfaces import IBuyXGetXFreeableMarker
+from getpaid.discount.browser.interfaces import ICodeDiscountableMarker
 
 from Products.PloneGetPaid.interfaces import IPayableMarker
 
@@ -19,7 +20,8 @@ class ContentControl(BrowserView):
         """
         return IPayableMarker.providedBy(self.context) and \
             not IDiscountableMarker.providedBy(self.context) and \
-            not IBuyXGetXFreeableMarker.providedBy(self.context)
+            not IBuyXGetXFreeableMarker.providedBy(self.context) and \
+            not ICodeDiscountableMarker.providedBy(self.context)
     
     isPossibleDiscountable.__roles__ = None
     
@@ -36,3 +38,10 @@ class ContentControl(BrowserView):
         return IBuyXGetXFreeableMarker.providedBy(self.context)
 
     isBuyXGetXfreeable.__roles__ = None
+
+    def isCodeDiscountable(self):
+        """does the context implement the ICodeDiscountableMarker interface
+        """
+        return ICodeDiscountableMarker.providedBy(self.context)
+
+    isCodeDiscountable.__roles__ = None
